function [X,IC] = SOequi(theta,phi,r,l,h)
%the potential and initial condition for non-rotational SO(4)-equivariant
%Willmore surfaces
a=cos(theta); b=sin(theta);
c=cos(phi); d=sin(phi);
R=sqrt(a^2+r^2*b^2);

m1=l;
m2=a*b*(r^2-1)*(R*c*l+d*r)/(R*r)+h*l*R/r;
k1=(1/2)*a*b*c*(-r^2+1)/R-(1/2)*h;
k2=(1/2)*r/R;
rho1=h^2*((1/2)*R^2*l^2/r^2+1/2)+h*a*b*(r^2-1)*(c*R*l^2/r^2+d*l/r+c/R)-(1/2)*R^2+l*a^2*c*d*b^2*(r^2-1)^2/(R*r)+(1/2)*l^2*(c^2*b^2*a^2*(r^2-1)^2-r^2)/r^2;
rho2=h*(R*l^2/r+r/R)+a*b*d*l*(r^2-1)/R+a*b*(r^2-1)*c*l^2/r;
rho=rho1+1i*rho2;


Y0=(1/R)*[1;a;0;b;0];
psi0=[h/R; h*a/R-b*c; -b*d*r/R; h*b/R+a*c; a*d/R];
e10=(1/R)*[l;l*a;a;l*b;r*b];
e20= [-(a*b*c*r^2-a*b*c+h*R)*l/(r*R);...
    -(a^2*b*c*l*r^2-a^2*b*c*l+h*R*a*l-R*b*d*r)/(r*R);...
    -r*b*c/R;...
    -(-a^3*c*l*r^2+a^3*c*l+a*c*l*r^2+h*R*b*l+R*a*d*r-a*c*l)/(R*r);
    a*c/R];
Yh0=[ (1/2)*(a^2*b^2*c^2*l^2*r^4-2*a^2*b^2*c^2*l^2*r^2+2*h*R*a*b*c*l^2*r^2+a^2*b^2*c^2*l^2-2*h*R*a*b*c*l^2+h^2*R^2*l^2+h^2*r^2+R^2*r^2+l^2*r^2)/(R*r^2);...
    (1/2)*(a^3*b^2*c^2*l^2*r^4-2*a^3*b^2*c^2*l^2*r^2+2*h*R*a^2*b*c*l^2*r^2-2*R*a*b^2*c*d*l*r^3+a^3*b^2*c^2*l^2-2*h*R*a^2*b*c*l^2+2*R*a*b^2*c*d*l*r+h^2*R^2*a*l^2-2*h*R^2*b*d*l*r-2*h*R*b*c*r^2+h^2*a*r^2-R^2*a*r^2+a*l^2*r^2)/(R*r^2);...
    ((R*b*c*l-b*d*r)*h+a*l*(b^2*c^2*r^2-b^2*c^2+1))/R;...
    (1/2)*(a^2*b^3*c^2*l^2*r^4-2*a^2*b^3*c^2*l^2*r^2+2*h*R*a*b^2*c*l^2*r^2+2*R*a^2*b*c*d*l*r^3+2*h*a*b^2*d*l*r^3+a^2*b^3*c^2*l^2-2*h*R*a*b^2*c*l^2-2*R*a^2*b*c*d*l*r+h^2*R^2*b*l^2-2*h*a*b^2*d*l*r-b^3*r^4+2*h*R*a*c*r^2+h^2*b*r^2+2*h*a*d*l*r+b^3*r^2+b*l^2*r^2-b*r^2)/(R*r^2);...
    -(a^2*b*c^2*l*r^2-a^2*b*c^2*l+h*R*a*c*l-h*a*d*r-b*l*r^2)/(R*r)];

f1=(1/sqrt(2))*(Y0+Yh0);  f2=(1/sqrt(2))*(-Y0+Yh0);
IC=[f1,f2,e10,e20,psi0];
 

A0=@(z)[0     m1     0      0       0;
       m1 0        0      0       0;
       0       0        0     -m2  -2*k1;
       0       0       m2   0       2*k2;
       0       0       2*k1  -2*k2   0];
    

A1=@(z)(1/(2*sqrt(2)))*[0               0               1+rho    -1i*(1+rho)  0;
                     0                0               1-rho    -1i*(1-rho)  0;
                     1+rho      -1+rho          0              0           0;
                     -1i*(1+rho)  1i*(1-rho)      0              0           0;
                     0                0               0               0          0];

X=@(z)[conj(A1(z)), A0(z), A1(z)];

end