#ifndef WILLMOREUTILS_H_INCLUDED
#define WILLMOREUTILS_H_INCLUDED

#include "mex.h"
#include "Eigen/Sparse"
#include <complex>
#include <stdexcept>

typedef Eigen::Triplet<std::complex<double> > ETD;

/*
 
// THIS BLOCK IS CURRENTLY NOT USED

class SparseComplex {
public:
  // Constructors
  SparseComplex() : rows_(0), cols_(0) {};
  SparseComplex(size_t rows, size_t cols) :  rows_(rows), cols_(cols) {};
  SparseComplex(size_t rows, size_t cols, size_t capacity)
      : rows_(rows), cols_(cols)  {
    triplets_.reserve(capacity);
  };
  // Query functions
  // Number of rows
  size_t rows() const {
    return rows_;
  }
  // Number of columns
  size_t cols() const {
    return cols_;
  }
  // Number of non-zero entries
  size_t nonZeros() const {
    return size_t(triplets_.size());
  }
  // Edit functions
  void insertTriplet( const ETD& ijk ) {
    triplets_.push_back(ijk);
  }
  // Edit functions
  void tripletReserve( const size_t capacity ) {
    triplets_.reserve(capacity);
  }
  // Edit functions
  void sortTriplets() {
    sort(triplets_.begin(), triplets_.end(), tripletLessThan<std::complex<double> >);
  }
  void resize( const size_t cols, const size_t rows) {
    cols_ = cols;
    rows_ = rows;
  }
  // Iterators
  vector<ETD>::const_iterator tripletBegin() const {
    return triplets_.begin();
  }
  vector<ETD>::const_iterator tripletEnd() const {
    return triplets_.end();
  }

private:
  size_t      rows_,     // number of rows
              cols_;     // number columns
  vector<ETD> triplets_; // vector of (row, columns, values)-triplets
                         // Note: value is complex<double>
};

// This function is essentially operator< for Eigen::Triplet. It is
// used when a vector of triplets is sorted. Ensures that elements in
// the vector are sorted 1) from first to last column, 2) from first
// to last row.
template<typename Scalar, typename Index=typename SparseMatrix<Scalar>::Index >
bool tripletLessThan (const Eigen::Triplet<Scalar,Index>& lhs, 
                      const Eigen::Triplet<Scalar,Index>& rhs) {
  return   (lhs.col()  < rhs.col())                            ? true :
         ( (lhs.col() == rhs.col()) && lhs.row() < rhs.row() ) ? true : false;
}

*/

// Copies the content of a MATLAB pointer to a real scalar into an object 
// of type T, where T can be, e.g., int or double.
template<class T>
T mxArray2ScalarReal( const mxArray* ptr ) {
  if (!(mxIsDouble(ptr))){
    throw std::runtime_error("MATLAB:mxArray2ScalarReal: input must be of type double.");
  }
  if ( mxGetM(ptr)!=1 || mxGetN(ptr)!=1 ) {
    throw std::runtime_error("MATLAB:mxArray2ScalarReal: input must be a scalar [1 x 1].");
  }
  T ret = (T) *mxGetPr(ptr);
  return ret;
}

// Copies the content of a MATLAB pointer to a complex scalar into an 
// object of type T, where T can be, e.g., int or double.
template<class T>
std::complex<T> mxArray2ScalarComplex( const mxArray* ptr ) {
  if (!(mxIsDouble(ptr))){
    throw std::runtime_error("MATLAB:mxArray2ScalarComplex: input must be of type double.");
  }
  if ( mxGetM(ptr)!=1 || mxGetN(ptr)!=1 ) {
    throw std::runtime_error("MATLAB:mxArray2ScalarComplex: input must be a scalar [1 x 1].");
  }
  const T* Re = mxGetPr(ptr);
  const T* Im = mxGetPi(ptr);
  std::complex<T> ret( (T) *Re , (Im!=NULL) ? (T) *Im : 0);
  return ret;
}

// Copies the content of the object pointed to by a MATLAB mxArray pointer 
// (pmat) to an Eigen sparse matrix of complex doubles (ret)
Eigen::SparseMatrix<std::complex<double> > matrixPointer2SparseComplex( const mxArray* pMat) {
    
    // Check data type of input matrix
    if (!(mxIsDouble(pMat))){
        throw std::runtime_error("MATLAB:matrixPointer2SparseComplex: input must be of type double.");
    }
    if (mxGetNumberOfDimensions(pMat) != 2){
        throw std::runtime_error("MATLAB:matrixPointer2SparseComplex: input must be two dimensional.");
    }
    
    // Get size of input matrix and pointers to data
    const mwSize M       = mxGetM(pMat);
    const mwSize N       = mxGetN(pMat);
    double * Ar          = mxGetPr(pMat);
    double * Ai          = mxGetPi(pMat); // result is a NULL pointer if matrix is real
    const bool isSparse  = mxIsSparse(pMat);
    const bool isComplex = (Ai != NULL);
    
    // Read a batch of triplets (row,columns,value) from input matrix
    std::vector<ETD> triplets;
    //SparseComplex spMat(M,N);
    if (isSparse) { // matrix is sparse
      mwIndex * ir = mxGetIr(pMat);   // row number
      mwIndex * jc = mxGetJc(pMat);   // "counter" for column number
      const mwIndex nnz = *(jc + N);  // total number of nonzeros
      triplets.reserve(nnz);
      //spMat.tripletReserve(nnz);
      mwIndex inz = 0;                // running number of non-zeroes
      mwIndex j   = 0;                // current column number
      while (inz < nnz) {
        mwIndex i = *ir++;            // Current row number
        while (*(jc+j+1) <= inz) {
          ++j;
        }
        const std::complex<double> k(*Ar++, (isComplex ? *Ai++ : 0));
        triplets.push_back( ETD(i,j,k) );
        //spMat.insertTriplet( ETD(i,j,k) );
        ++inz;
      }
    } else { // matrix is full
      const mwIndex nnz = M*N;        // total number of nonzeros
      triplets.reserve(nnz);
      //spMat.tripletReserve(nnz);
      for (mwIndex j=0; j<N; ++j) {
        for (mwIndex i=0; i<M; ++i) {
          const std::complex<double> k(*Ar++, (isComplex ? *Ai++ : 0));
          triplets.push_back( ETD(i,j,k) );
          //spMat.insertTriplet( ETD(i,j,k) );
        }
      }
    }
    
    // Construct output matrix from batch of triplets
    Eigen::SparseMatrix<std::complex<double> > ret(M,N);
    ret.setFromTriplets(triplets.begin(), triplets.end());
    //ret.setFromTriplets(spMat.tripletBegin(), spMat.tripletEnd());

    return ret;

}

// Copies the content of an Eigen sparse matrix of complex doubles to the 
// object pointed to by a MATLAB mxArray pointer (out).
mxArray* sparseComplex2MatrixPointer( const Eigen::SparseMatrix<std::complex<double> >& mat, const bool isComplex ) {
  
  // Initiate output as a sparse, matrix and get pointers to the data.
  mxArray* out = mxCreateSparse(mat.rows(), mat.cols(), mat.nonZeros(), isComplex ? mxCOMPLEX : mxREAL);
  double  * pr = mxGetPr(out);                    // real part
  double  * pi = isComplex ? mxGetPi(out) : NULL; // imaginary part
  mwIndex * ir = mxGetIr(out);                    // row number
  mwIndex * jc = mxGetJc(out);                    // "counter" for column number

  // Fill in output matrix by copying the input matrix
  *jc++        = 0;
  mwIndex inz  = 0;
  for (int j=0; j<mat.outerSize(); ++j) {
    Eigen::SparseMatrix<std::complex<double> >::InnerIterator it(mat,j);
    for ( ; it; ++it) {
      *pr++ = it.value().real();
      if (isComplex) {
        *pi++ = it.value().imag();
      }	
      *ir++ = it.row();
      ++inz;
    }
    *jc++ = inz;
  }

  // Return the output matrix. Note: mxCreateSparse ensures that
  // memory is NOT freed, when 'out' goes out of scope here, so
  // returning a pointer to it is OK.
  return out;

}

#endif // WILLMOREUTILS_H_INCLUDED