function [X,IC] = hypequi_a1b0(h,r,theta)
% The Bjorling potential for SO(1,3)-equivariant Willmore surfaces for
%the case a=1,b=0,c=1.  The parameter theta is optional. It only effects
%the initial condition

if nargin<3
theta=pi/2;
end
T=theta;
m1=0;
m2=0;
k1=-(1/2)*h;
k2=-r/2;
rho1=(1/2)*(h^2+1);
rho2=-r*h;
rho=rho1+1i*rho2;

Y0=[1; 0; 0; 0; 1];
  psi0=[h; 0; cos(T); sin(T); h];
  e10=[0;1;0;0;0];
  e20= [0; 0; sin(T); -cos(T); 0];
  Yh0=[(h^2+1)/2; 0; h*cos(T); h*sin(T); (h^2-1)/2];
  
  f1=(1/sqrt(2))*(Y0+Yh0);  f2=(1/sqrt(2))*(-Y0+Yh0);
  IC=[f1,f2,e10,e20,psi0];
    
A0=@(z)[0     m1     0      0       0;
       m1   0        0      0       0;
       0       0        0     -m2  -2*k1;
       0       0       m2   0       2*k2;
       0       0       2*k1  -2*k2   0];
    

A1=@(z)(1/(2*sqrt(2)))*[0               0               1+rho    -1i*(1+rho)  0;
                     0                0               1-rho    -1i*(1-rho)  0;
                     1+rho      -1+rho          0              0           0;
                     -1i*(1+rho)  1i*(1-rho)      0              0           0;
                     0                0               0               0          0];

X=@(z)[conj(A1(z)), A0(z), A1(z)];

end