function [X,IC] = hypequi_r1(m,q,h,theta)
%The general potential and initial condition (c non-zero) for hyperbolic Hopf surface analogues,
% where a=cos(theta,b=sin(theta), c=sqrt(cos(2*theta))
%There is a constraint q^2 <=  1/(sin(theta))^2,
%and 0 <= theta <= pi/4
a=cos(theta); b=sin(theta);
c=sqrt(cos(2*theta)); 

if q^2<=1/b^2 && theta >=0 && theta<pi/4
      p=(-sqrt(-b^2*q^2+1)*b*c*m+h*a*m+q*a^2)/(a*c);
      m1=m;
      m2=a*c*q-p;
      k1=(1/2)*sqrt(-q^2*b^2+1)*b*c/a-(1/2)*h;
      k2=-c/2;
      rho1=(1/2)*(h^2*a^2-2*h*sqrt(-b^2*q^2+1)*a*b*c+a^2*p^2+q^2*c^4-2*p*q*a^3*c-a^2*m^2+c^2)/a^2;
      rho2=-(-q*a^2*c*m+h*a*c+a*m*p+sqrt(-b^2*q^2+1)*b)/a;
      
      Y0=[a; 0; b; 0; c];
      psi0=[h*a;-b^2*q;h*b-c*sqrt(-q^2*b^2+1)/a;a*q*b;h*c+b*sqrt(1-q^2*b^2)/a];
      e10=[m*a;a;m*b;b;m*c];
      e20= [a*p-c*q;-sqrt(-b^2*q^2+1)*b; p*b; sqrt(-b^2*q^2+1)*a; -a*q+c*p];
      Yh0= [(1/2)*(a^2*h^2+a^2*m^2+a^2*p^2-2*a*c*p*q+c^2*q^2+1)/a;...
          -(h*q*a*b^2+sqrt(-b^2*q^2+1)*p*a*b-sqrt(-b^2*q^2+1)*q*b*c-a^2*m)/a;...
          (1/2)*(h^2*a^2*b+a^2*b*m^2+p^2*a^2*b-q^2*b*c^2-2*sqrt(-b^2*q^2+1)*a*c*h-b)/a^2;...
          (1/2)*(2*a^3*b*q*h+(-q*c*(c^2+1)+2*p*a^3)*sqrt(-b^2*q^2+1)+2*m*b*a^2)/a^2;...
          (1/2)*(a^2*c*h^2+2*h*sqrt(-b^2*q^2+1)*a*b+(a^2*m^2+a^2*p^2+q^2-1)*c-2*p*q*a^3)/a^2];
  f1=(1/sqrt(2))*(Y0+Yh0);  f2=(1/sqrt(2))*(-Y0+Yh0);
  IC=[f1,f2,e10,e20,psi0];
  rho=rho1+1i*rho2;
  
  A0=@(z)[0     m1     0      0       0;
       m1 0        0      0       0;
       0       0        0     -m2  -2*k1;
       0       0       m2   0       2*k2;
       0       0       2*k1  -2*k2   0];
    

  A1=@(z)(1/(2*sqrt(2)))*[0               0               1+rho    -1i*(1+rho)  0;
                     0                0               1-rho    -1i*(1-rho)  0;
                     1+rho      -1+rho          0              0           0;
                     -1i*(1+rho)  1i*(1-rho)      0              0           0;
                     0                0               0               0          0]; 
X=@(z)[conj(A1(z)), A0(z), A1(z)];
else
  disp('Invalid input. Data must satisfy  |q|<=1/|sin(theta)| & theta >=0 & theta<=pi/4');  
  X=0;
  IC=0;
end
end