function g = projplot(Y,k,curve)
%The projection to R^3 of Y=(Y0,Y1,Y2,Y3,Y4) give by 
%(Y1,...[ skip Y|k| ], ...,Y4)/(Y0-sign(k)*Y|k|)
%If Y0/Yk is positive then it's the projection to the Poincare ball
%e.g. if k=1 the formula is (Y2,Y3,Y4)/(Y0-Y1).
%
%curve is an integer n. plots the curve given by the n'th column of Y in a
%different color.  If n=0, no curve is plotted. The default is no curve.

if nargin<3
    curve=0;
end
Ydims=size(Y); xpoints=Ydims(1)/5; ypoints=Ydims(2);  
g=zeros(xpoints*3,ypoints);
ind=[1 2 3]; K=abs(k);
ind(K:3)=ind(K:3)+1;

for row=1:xpoints
  for j=1:ypoints
      g(row,j)=Y(5*(row-1)+1+ind(1),j)/(Y(5*row-4,j)-sign(k)*Y(5*(row-1)+1+K,j));
      g(xpoints+row,j)=Y(5*(row-1)+1+ind(2),j)/(Y(5*row-4,j)-sign(k)*Y(5*(row-1)+1+K,j));
      g(2*xpoints+row,j)=Y(5*(row-1)+1+ind(3),j)/(Y(5*row-4,j)-sign(k)*Y(5*(row-1)+1+K,j));
  end
end  

surf(g(1:xpoints, :), g(xpoints+1: 2*xpoints, :),  g(2*xpoints+1: 3*xpoints, :),'Clipping','off','BackFaceLight','unlit','EdgeAlpha',0.3,'FaceAlpha',1,'LineWidth',1,'FaceLighting','gouraud','DiffuseStrength',0.7,'EdgeLighting','gouraud','EdgeColor','w','FaceColor',[0.7,0.75,0.9])
daspect([1 1 1])
hold all
if curve
plot3(g(1:xpoints, curve:curve), g(xpoints+1: 2*xpoints, curve:curve),  g(2*xpoints+1: 3*xpoints, curve:curve),'color',[0.7 0 0],'LineWidth',1.2)
end
hold off
end

